#' @importFrom mlr3proba TaskSurv
#' @export
mlr3proba::TaskSurv

#' @importFrom mlr3proba TaskDens
#' @export
mlr3proba::TaskDens

#' @importFrom mlr3proba pecs
#' @export
mlr3proba::pecs

#' @importFrom mlr3proba as_task_surv
#' @export
mlr3proba::as_task_surv

#' @importFrom mlr3proba as_task_dens
#' @export
mlr3proba::as_task_dens

#' @importFrom mlr3proba as_prediction_surv
#' @export
mlr3proba::as_prediction_surv

#' @importFrom mlr3proba as_prediction_dens
#' @export
mlr3proba::as_prediction_dens
